// povray +ilorenz.pov scene.ini

#declare VC = <0.2,0.4,24>; // Center of the attractor
#declare VIEWANGLE = 0;
#declare VP = 60*<cos(degrees(VIEWANGLE)),sin(degrees(VIEWANGLE)),0>;
#declare VU = <0,0,1>;
#declare VD = vnormalize(-VP);
#declare VR = vnormalize(vcross(VD,VU));
#declare RADIUS = 0.1;

camera {
   location VP
   up y
   right image_width*x/image_height
   angle 60
   sky VU
   look_at VP + VD
}

global_settings {
   ambient_light rgb <1,1,1>
   assumed_gamma 2.0
}

background {
   color rgb <0,0,0>
}

light_source {
   VP
   color 0.5*<1,1,1>
}
light_source {
   VP + 20*VR
   color <1,1,1>
}

#declare thefinish = finish {
   ambient 0.1
   diffuse 0.5
   specular 0.5
}

// N: Total number of iterations
// h, a, b, c: Parameters describing the attractor
// x0, y0, z0: Seed position
// rad: Radius of spheres/cylinders
#macro lorenz(h, a, b, c, x0, y0, z0, N, rad)
   #local i = 0;
   #local xmin = 1000000;
   #local ymin = 1000000;
   #local zmin = 1000000;
   #local xmax = -1000000;
   #local ymax = -1000000;
   #local zmax = -1000000;
   union {
      #while (i < N)
         #local x1 = x0 + h * a * (y0 - x0);
         #local y1 = y0 + h * (x0 * (b - z0) - y0);
         #local z1 = z0 + h * (x0 * y0 - c * z0);
         #if (i > 1000)
            sphere {
               <x0,y0,z0>, rad
					texture {
               	pigment { color rgb <0,i/N,1-i/N> }
						finish { thefinish }
					}
            }
            /*
            cylinder {
               <x0,y0,z0>, <x1,y1,z1>, rad
               texture {
                  pigment { color rgb <i/N,i/N,1-i/N> }
					}
            } 
				*/
         #end
         #local i = i + 1;
         #local x0 = x1;
         #local y0 = y1;
         #local z0 = z1;
         #if (x0 < xmin) #local xmin = x0; #end
         #if (y0 < ymin) #local ymin = y0; #end
         #if (z0 < zmin) #local zmin = z0; #end
         #if (x0 > xmax) #local xmax = x0; #end
         #if (y0 > ymax) #local ymax = y0; #end
         #if (z0 > zmax) #local zmax = z0; #end
      #end
   }
   #debug concat(str((xmin+xmax)/2,0,6)," ",str((ymin+ymax)/2,0,6)," ",str((zmin+zmax)/2,0,6))
#end

object {
   lorenz(0.001,10,28,8.0/3.0,0.1,0.0,0.0,100000,RADIUS)
   translate -VC
	rotate <0,0,30>
}

