// povray +imri.pov mri.ini
// z axis is "up"

// Definitions
#declare NX = 200;
#declare NY = 160;
#declare NZ = 160;
#declare DD = <NX,NY,NZ>;
#declare VP = <0,260,0>; // Default camera position

global_settings { 
	ambient_light <1,1,1> 
	assumed_gamma 1.8
}
background { 
	color rgb <0,0,0> 
}

// Standard perspective camera
camera {
   location VP
   up y
   right -image_width*x/image_height
   angle 60
   sky <0,0,1>
   look_at <0,0,0> // Data centered at the origin
}

// Two light sources, both attached to the camera
light_source {
   VP + <0,0,NZ/2>
   color rgb <1,1,1>
}
light_source {
   VP
   color rgb <1,1,1>/2
}

// ============================================================= Media
// The the media volume defined by the df3 file
#declare theinterior = interior {
   media {
      intervals 100
		ratio 0.5
      samples 2,2
		method 2
      emission <1,1,1> / 100
      absorption <1,1,1> / 1000
      scattering { 1, <0,0,0> }
      confidence 0.999
      variance 1/1000
      density {
        	density_file df3 "mri.df3" 
			interpolate 1
/*       Brain on fire
			color_map {
   			[0.00 rgb <0,0,0>]
				[0.01 rgb <0 0 1>]
   			[0.40 rgb <1,1,0>]
				[0.60 rgb <1,0,0>]
   			[1.00 rgb <1,0,0>]
			}
*/
         color_map {
            [0.00 rgb <0,0,0>]
            [1.00 rgb <1,1,1>]
         }
/*       Corpus callosum
         color_map {
            [0.00 rgb <0,0,0>]
				[0.50 rgb <0,0,0>]
            [0.60 rgb <1,1,0>]
				[0.70 rgb <1,0,0>]
            [1.00 rgb <1,0,0>]
         }
*/
		}
	}
}

// The box in which the media exists
box {
   <0,0,0>, <1,1,1>
   pigment { rgbf 1 }
   interior { theinterior }
   hollow
	translate <-0.5,-0.5,-0.5>
	scale DD
	scale <1,1,-1> // MRI scan is upsidedown
	rotate <0,0,360*clock>
}

/* Box for media with a cutting plane
difference {
	box { <0,0,0>, <1,1,1> }
   plane {
      <0,1,0>, 0
      rotate <0,0,-135>
		translate <0.5,0.5,0.5>
   }
  	pigment { rgbf 1 }
  	interior { theinterior }
  	hollow
  	translate <-0.5,-0.5,-0.5>
  	scale DD
	scale <1,1,-1> // MRI scan is upsidedown
  	rotate <0,0,360*clock>
}
*/

// ============================================================= Isosurface(s)
/*
#declare isofinish = finish {
   ambient 0.1
   diffuse 0.5
   specular 0.3
}
//#include "200.inc"
//#include "180.inc"
//#include "160.inc"
//#include "140.inc"
//#include "120.inc"
//#include "100.inc"
#include "80.inc"
//#include "60.inc"
object {
	mesh2 { themesh } 
	scale <1,1,-1> // MRI scan is upsidedown
	texture {
		pigment { color rgbt <0.8,0.8,0.1,0.85> }
		finish { isofinish }
	}
}
#include "200.inc"
object { 
   mesh2 { themesh }
	scale <1,1,-1> // MRI scan is upsidedown
   texture {
      pigment { color rgbt <1.0,0.2,0.2,0.0> }
      finish { isofinish }
   }
}
*/

// ============================================================= Heat flow Vectors
// File consists of x,y,z flow direction and flow strength
/*
#declare arrowradius = 0.01;
#declare arrowfinish = finish {
   ambient 0.1
   diffuse 0.6
   specular 0.6
}
union {
#fopen DATAFILE "vectors.txt" read
#while ( defined(DATAFILE) )
   #read (DATAFILE, x1, y1, z1, x2, y2, z2, m1)
	#declare p1 = <x1,y1,z1>;
	#declare p2 = <x2,y2,z2>;
	#declare p3 = p1+m1*(p2-p1)/6;
	#declare p4 = p3+m1*(p2-p1)/12;
	#declare thecolour = rgb <m1,0.2,1-m1>;
	cylinder {
		p1, p3, arrowradius
		texture {
			pigment { color thecolour }
			finish { arrowfinish }
		}
	}
   cone {
      p3, 2*arrowradius, p4, 0
      texture {
         pigment { color thecolour }
         finish { arrowfinish }
      }
   }
#end
#fclose DATAFILE
   scale DD/2
   rotate <0,0,360*clock>
}
*/

// ============================================================= Bounding box
// Texture for bounding box
#declare boxfinish = finish {
   ambient 0.30
   brilliance 3
   diffuse 0.4
   metallic
   specular 0.70
   roughness 1/60
   reflection 0.25
}
#declare bboxtexture1 = texture {
   pigment { rgb <0.5,0.5,1.0> }
	finish { boxfinish }
}
#declare bboxtexture2 = texture {
   pigment { rgb <0.5,1.0,0.5> }
   finish { boxfinish }
}
#declare RADIUS1 = 1;
#declare RADIUS2 = 1.5;

// Corners of bounding box
union {
	sphere { < 0, 0, 0>, RADIUS2 }
	sphere { < 0,NY, 0>, RADIUS2 }
	sphere { <NX,NY, 0>, RADIUS2 }
	sphere { <NX, 0, 0>, RADIUS2 }
	sphere { < 0, 0,NZ>, RADIUS2 }
	sphere { < 0,NY,NZ>, RADIUS2 }
	sphere { <NX,NY,NZ>, RADIUS2 }
	sphere { <NX, 0,NZ>, RADIUS2 }
	texture { bboxtexture2 }
	translate -DD/2
   rotate <0,0,360*clock>
}

// Edges of the bounding box
union {
	cylinder { < 0, 0, 0>, <NX, 0, 0>, RADIUS1 }
	cylinder { < 0, 0, 0>, < 0,NY, 0>, RADIUS1 }
	cylinder { < 0, 0, 0>, < 0, 0,NZ>, RADIUS1 }
	cylinder { <NX,NY,NZ>, < 0,NY,NZ>, RADIUS1 }
	cylinder { <NX,NY,NZ>, <NX, 0,NZ>, RADIUS1 }
	cylinder { <NX,NY,NZ>, <NX,NY, 0>, RADIUS1 }
	cylinder { < 0, 0,NZ>, <NX, 0,NZ>, RADIUS1 }
	cylinder { < 0, 0,NZ>, < 0,NY,NZ>, RADIUS1 }
	cylinder { <NX,NY, 0>, <NX, 0, 0>, RADIUS1 }
	cylinder { <NX,NY, 0>, < 0,NY, 0>, RADIUS1 }
	cylinder { < 0,NY, 0>, < 0,NY,NZ>, RADIUS1 }
	cylinder { <NX, 0, 0>, <NX, 0,NZ>, RADIUS1 }
	texture { bboxtexture1 }
	translate -DD/2
   rotate <0,0,360*clock>
}

